import React, {useEffect} from 'react';
import {Text, Pressable} from 'react-native';
import {
	NavigationContainer,
	useNavigationContainerRef,
} from '@react-navigation/native';
import {createNativeStackNavigator} from '@react-navigation/native-stack';
import SignIn from './screens/SignIn';
import useLoggedIn from './hooks/useLoggedIn';
import SignUp from './screens/SignUp';
import Buckets from './screens/Buckets';
import Settings from './screens/Settings';

const Stack = createNativeStackNavigator();

const Navigation = () => {
	const [isInitializing, user] = useLoggedIn();

	console.log('[user]', user);

	if (isInitializing) {
		return <Text>Loading...</Text>;
	}

	return (
		<NavigationContainer>
			<Stack.Navigator initialRouteName={!!user ? 'Buckets' : 'SignIn'}>
				<Stack.Screen
					name="SignIn"
					component={SignIn}
					options={{title: 'Sign In'}}
				/>
				<Stack.Screen
					name="SignUp"
					component={SignUp}
					options={{title: 'Sign Up'}}
				/>
				{!!user ? (
					<React.Fragment>
						<Stack.Screen
							name="Buckets"
							component={Buckets}
							options={({navigation}) => ({
								title: 'S3 Buckets',
								headerRight: () => (
									<Pressable onPress={() => navigation.navigate('Settings')}>
										<Text style={{fontSize: 24, color: '#000000'}}>⚙</Text>
									</Pressable>
								),
							})}
						/>
						<Stack.Screen
							name="Settings"
							component={Settings}
							options={{title: 'Settings'}}
						/>
					</React.Fragment>
				) : null}
			</Stack.Navigator>
		</NavigationContainer>
	);
};

export default Navigation;
