import React, {useCallback} from 'react';
import {StyleSheet, View, Text, Button, TextInput} from 'react-native';
import {KeyboardAwareScrollView} from 'react-native-keyboard-aware-scroll-view';
import useLogout from '../hooks/useLogout';
import {useNavigation} from '@react-navigation/native';

const Settings = () => {
	const logOut = useLogout();
	const navigation = useNavigation();

	const onLogout = useCallback(() => {
		logOut().then(() => {
			navigation.reset({index: 0, routes: [{name: 'SignIn'}]});
		});
	}, [logOut]);

	return (
		<KeyboardAwareScrollView style={styles.root}>
			<View style={styles.button}>
				<Button onPress={onLogout} title="Sign out" />
			</View>
		</KeyboardAwareScrollView>
	);
};

const styles = StyleSheet.create({
	root: {
		flex: 1,
		backgroundColor: '#FEFEFE',
		padding: 10,
	},
	input: {
		height: 40,
		margin: 12,
		borderWidth: 1,
		padding: 10,
		borderRadius: 3,
		backgroundColor: '#DDDDDD',
		color: '#000000',
	},
	button: {
		margin: 12,
		marginBottom: 32,
	},
});

export default Settings;
