import React, {useState, useCallback} from 'react';
import {
	View,
	Text,
	TextInput,
	Button,
	Pressable,
	ToastAndroid,
	StyleSheet,
} from 'react-native';
import {KeyboardAwareScrollView} from 'react-native-keyboard-aware-scroll-view';
import {useNavigation} from '@react-navigation/native';
import useLogin from '../hooks/useLogin';

const SignIn = () => {
	const navigation = useNavigation();
	const [email, setEmail] = useState('');
	const [pass, setPass] = useState('');
	const logIn = useLogin();

	const onSubmit = useCallback(() => {
		if (!email || !pass) {
			ToastAndroid.show(
				'Error! You need to provide both an email and a password',
				ToastAndroid.SHORT,
			);
			return;
		}

		logIn(email, pass)
			.then(() => {
				console.log('asdasd');
				navigation.reset({index: 0, routes: [{name: 'Buckets'}]});
			})
			.catch(() => {});
	}, [email, pass, logIn, navigation]);

	const onSignup = useCallback(() => {
		navigation.navigate('SignUp');
	}, []);

	return (
		<KeyboardAwareScrollView style={styles.root}>
			<Text style={styles.title}>BrowseS3</Text>
			<Text style={styles.subtitle}>Made by: Fándly Gergő-Zoltán</Text>
			<Text style={styles.welcome}>Welcome! Please sign in to continue!</Text>
			<TextInput
				style={styles.input}
				placeholder="Email"
				value={email}
				onChangeText={setEmail}
				autoComplete="email"
			/>
			<TextInput
				style={styles.input}
				placeholder="Password"
				value={pass}
				onChangeText={setPass}
				autoComplete="password"
				secureTextEntry
			/>
			<View style={styles.button}>
				<Button onPress={onSubmit} title="Sign in" />
			</View>
			<Pressable onPress={onSignup}>
				<Text style={styles.signUp}>No account? Sign up here!</Text>
			</Pressable>
		</KeyboardAwareScrollView>
	);
};

const styles = StyleSheet.create({
	root: {
		flex: 1,
		backgroundColor: '#FEFEFE',
		padding: 10,
	},
	title: {
		fontSize: 32,
		textAlign: 'center',
		marginTop: 32,
		color: '#000000',
	},
	subtitle: {
		color: '#000000',
		marginBottom: 132,
		textAlign: 'right',
	},
	welcome: {
		fontSize: 20,
		color: '#000000',
		marginBottom: 32,
		textAlign: 'center',
	},
	input: {
		height: 40,
		margin: 12,
		borderWidth: 1,
		padding: 10,
		borderRadius: 3,
		backgroundColor: '#DDDDDD',
		color: '#000000',
	},
	button: {
		margin: 12,
		marginBottom: 32,
	},
	signUp: {
		color: '#CCCCCC',
		fontSize: 12,
		textAlign: 'center',
		textDecorationLine: 'underline',
	},
});

export default SignIn;
