import React, {useState, useCallback} from 'react';
import {StyleSheet, View, Text, TextInput, Button} from 'react-native';
import {KeyboardAwareScrollView} from 'react-native-keyboard-aware-scroll-view';
import useSignup from '../hooks/useSignup';
import {useNavigation} from '@react-navigation/native';

const SignUp = () => {
	const [email, setEmail] = useState('');
	const [pass, setPass] = useState('');
	const signUp = useSignup();
	const navigation = useNavigation();

	const onSubmit = useCallback(() => {
		if (!email || !pass) {
			ToastAndroid.show(
				'Error! You need to provide both an email and a password',
				ToastAndroid.SHORT,
			);
			return;
		}

		signUp(email, pass)
			.then(() => {
				console.log('asdasd');
				navigation.reset({index: 0, routes: [{name: 'Buckets'}]});
			})
			.catch(() => {});
	}, [email, pass, signUp, navigation]);

	return (
		<KeyboardAwareScrollView style={styles.root}>
			<Text style={styles.help}>Let's create a new user for you!</Text>
			<TextInput
				style={styles.input}
				placeholder="Email"
				value={email}
				onChangeText={setEmail}
				autoComplete="email"
			/>
			<TextInput
				style={styles.input}
				placeholder="Password"
				value={pass}
				onChangeText={setPass}
				autoComplete="password-new"
				secureTextEntry
			/>
			<View style={styles.button}>
				<Button onPress={onSubmit} title="Sign up" />
			</View>
		</KeyboardAwareScrollView>
	);
};

const styles = StyleSheet.create({
	root: {
		flex: 1,
		backgroundColor: '#FEFEFE',
		padding: 10,
	},
	help: {
		color: '#000000',
		fontSize: 18,
		textAlign: 'center',
		marginBottom: 32,
	},
	input: {
		height: 40,
		margin: 12,
		borderWidth: 1,
		padding: 10,
		borderRadius: 3,
		backgroundColor: '#DDDDDD',
		color: '#000000',
	},
	button: {
		margin: 12,
		marginBottom: 32,
	},
});

export default SignUp;
